# Changelog

## 0.0.2 (2025-12-07)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/kausate/sdk-python/compare/v0.0.1...v0.0.2)

### Chores

* update SDK settings ([1ab15ad](https://github.com/kausate/sdk-python/commit/1ab15ad381e8f4cce3876bd6095b39806a26b078))
* update SDK settings ([8599ed2](https://github.com/kausate/sdk-python/commit/8599ed2b2fb0cb822b671867fc25b7f6c41bf03f))
